#
# spec file for package kf6-kpeople
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define qt6_version 6.6.0

%define rname kpeople
# Full KF6 version (e.g. 6.2.0)
%{!?_kf6_version: %global _kf6_version %{version}}
# Last major and minor KF6 version (e.g. 6.0)
%{!?_kf6_bugfix_version: %define _kf6_bugfix_version %(echo %{_kf6_version} | awk -F. '{print $1"."$2}')}
%bcond_without released
Name:           kf6-kpeople
Version:        6.2.0
Release:        1.1
Summary:        Library for access to contacts and identity holders
License:        LGPL-2.1-or-later
URL:            https://www.kde.org
Source:         %{rname}-%{version}.tar.xz
%if %{with released}
Source1:        %{rname}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  kf6-extra-cmake-modules >= %{_kf6_version}
BuildRequires:  cmake(KF6CoreAddons) >= %{_kf6_version}
BuildRequires:  cmake(KF6Contacts) >= %{_kf6_version}
BuildRequires:  cmake(KF6I18n) >= %{_kf6_version}
BuildRequires:  cmake(KF6ItemViews) >= %{_kf6_version}
BuildRequires:  cmake(KF6WidgetsAddons) >= %{_kf6_version}
BuildRequires:  cmake(Qt6DBus) >= %{qt6_version}
BuildRequires:  cmake(Qt6Gui) >= %{qt6_version}
BuildRequires:  cmake(Qt6Qml) >= %{qt6_version}
BuildRequires:  cmake(Qt6Quick) >= %{qt6_version}
BuildRequires:  cmake(Qt6Sql) >= %{qt6_version}
BuildRequires:  cmake(Qt6ToolsTools) >= %{qt6_version}
BuildRequires:  cmake(Qt6Widgets) >= %{qt6_version}

%description
A library that provides access to all contacts and the people who hold them.

%package imports
Summary:        QML imports for kpeople
Requires:       libKF6People6 = %{version}

%description imports
This package provides support to use KPeople with the QtQuick framework.

%package -n libKF6People6
Summary:        Library for access to contacts and identity holders
Requires:       kf6-kpeople >= %{version}
Requires:       qt6-sql-sqlite >= %{qt6_version}

%description -n libKF6People6
A library that provides access to all contacts and the people who hold them.

%package devel
Summary:        Library for access to contacts and identity holders
Requires:       libKF6People6 = %{version}
Requires:       cmake(Qt6Core) >= %{qt6_version}

%description devel
A library that provides access to all contacts and the people who hold them.
Development files for kpeople.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf6 -DBUILD_QCH:BOOL=TRUE \
           -DENABLE_EXAMPLES:BOOL=FALSE

%kf6_build

%install
%kf6_install

%find_lang kpeople6

%ldconfig_scriptlets -n libKF6People6

%files
%{_kf6_debugdir}/kpeople.categories
%{_kf6_debugdir}/kpeople.renamecategories
%dir %{_kf6_plugindir}/kpeople/
%dir %{_kf6_plugindir}/kpeople/datasource/
%{_kf6_plugindir}/kpeople/datasource/KPeopleVCard.so

%files imports
%{_kf6_qmldir}/org/kde/people/

%files -n libKF6People6
%license LICENSES/*
%doc README.md
%{_kf6_libdir}/libKF6People.so.*
%{_kf6_libdir}/libKF6PeopleBackend.so.*
%{_kf6_libdir}/libKF6PeopleWidgets.so.*

%files devel
%doc %{_kf6_qchdir}/KF6People.*
%{_kf6_cmakedir}/KF6People/
%{_kf6_includedir}/KPeople/
%{_kf6_libdir}/libKF6People.so
%{_kf6_libdir}/libKF6PeopleBackend.so
%{_kf6_libdir}/libKF6PeopleWidgets.so

%files lang -f kpeople6.lang

%changelog
* Mon May  6 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.2.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/6.2.0/
- No code change since 6.1.0
* Fri Apr  5 2024 Christophe Marin <christophe@krop.fr>
- Update to 6.1.0
  * New feature release
- Changes since 6.0.0:
  * update version for new release
* Wed Feb 21 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 6.0.0
  * New bugfix release
  * Release announcement not available yet
- Changes since 5.249.0:
  * update version for new release
* Wed Jan 31 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.249.0 (6.0 RC 2):
  * New bugfix release
  * For more details see https://kde.org/announcements/megarelease/6/rc2/
* Mon Jan 15 2024 Fabian Vogt <fabian@ritter-vogt.de>
- Update to 5.248.0 (6.0 RC 1)
  * For more details please see:
    https://kde.org/announcements/megarelease/6/rc1/
* Sat May 27 2023 Christophe Marin <christophe@krop.fr>
- Init kf6-kpeople
